%%
%% This is file `htexture.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `textures')
%% 
%% File: hyperref.dtx Copyright 1995-2000 Sebastian Rahtz,
%%
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%%
%% It may be distributed under the conditions of the LaTeX Project Public
%% License, either version 1.2 of this license or (at your option) any
%% later version.  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%%
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%%
\def\literalps@out#1{\special{rawpostscript #1}}%
\def\pdf@setheight{%
  \literalps@out{%
    \strip@pt@and@otherjunk\baselineskip
    \space 2 sub
    PDFToDvips /HyperBase exch def
  }%
}
\providecommand\@pdfview{XYZ pdf@hoff pdf@voff null}
\providecommand\@pdfviewparams{ pdf@hoff pdf@voff null}
\def\PSHyperAnchorStart{\literalps@out{HyperStart }}
\def\PSHyperAnchorEnd{%
  \pdf@setheight
  \literalps@out{HyperAutoEnd HyperAutoVoff }%
}
\def\PSHyperLinkStart{\literalps@out{HyperStart }}
\def\PSHyperLinkEnd{%
  \pdf@setheight
  \literalps@out{HyperAutoEnd}%
}
\def\PSHyperRectStart{\literalps@out{HyperStart }}
\def\PSHyperRectEnd{\literalps@out{HyperEnd HyperVoff }}
\special{prepostscript
  /vsize { \Hy@pageheight } def
  /DvipsToPDF { } def
  /PDFToDvips { } def
  /HyperBorder  { 1 PDFToDvips } def
  /HyperVoff {
    currentpoint exch pop vsize 72 sub
    exch DvipsToPDF sub /pdf@voff exch def
  } def
  /HyperAutoVoff {
    currentpoint exch pop
    vsize 72 sub exch DvipsToPDF
    HyperBase sub % baseline skip
    sub /pdf@voff exch def
  } def
  /HyperStart {
    currentpoint
    HyperBorder add /pdf@lly exch def
    dup DvipsToPDF  /pdf@hoff exch def
    HyperBorder sub /pdf@llx exch def
  } def
  /HyperAutoEnd  {
    currentpoint
    HyperBase sub /pdf@ury exch def
    /pdf@urx exch def
  } def
  /HyperEnd  {
    currentpoint
    HyperBorder sub /pdf@ury exch def
    HyperBorder add /pdf@urx exch def
  } def
  systemdict
  /pdfmark known not
  {userdict /pdfmark systemdict /cleartomark get put} if
}
\AtBeginDocument{%
  \ifHy@colorlinks
    \def\@pdfborder{0 0 0}%
  \fi
}
\providecommand\@pdfborder{0 0 1}
\AtBeginDocument{%
  \def\@pdfproducer{Textures + Distiller}%
}
\endinput
%%
%% End of file `htexture.def'.
